@@ -9,26 +9,21 @@ p <- ggplot(d, aes(x, y)) + geom_line(colour = "dodgerblue", size = 2) +
   geom_point(colour = "orange", size = 2) + facet_wrap(~grp) +
   labs(title = "A plot", subtitle = "Plot subtitle", caption = "Figure 1. A caption.")
 
-web <- "http://www.memeaholic.me/wp-content/uploads/2013/04/philosoraptor1.png" # a png version
 loc <- system.file("philosoraptor.jpg", package = "memery")
 x <- "NULL"
-out <- c("meme_test.png", "meme_test.jpg")
+out <- tempfile("meme_", fileext = c(".png", ".jpg"))
 lab <- c("What to call my R package?", "Perhaps...")
 
 test_that("meme runs as expected", {
   expect_error(meme("in", "lab", "out"), "`img` must be a jpg or png. Check file extension.")
   expect_error(meme("in.jpg", "lab", "out"), "Output must be a jpg or png. Check file extension.")
-  expect_error(meme(local, c("lab1", "lab2"), "out.jpg", label_pos = text_position(1)),
+  expect_error(meme(loc, c("lab1", "lab2"), "out.jpg", label_pos = text_position(1)),
                "`label_pos` list elements must be same length as `label`.")
 
   expect_is(meme(loc, lab[1], out[1]), x)
   expect_is(meme(loc, lab, out[1]), x)
   expect_is(meme(loc, lab[1], out[2]), x)
   expect_is(meme(loc, lab, out[2]), x)
-  expect_is(meme(web, lab[1], out[1]), x)
-  expect_is(meme(web, lab, out[1]), x)
-  expect_is(meme(web, lab[1], out[2]), x)
-  expect_is(meme(web, lab, out[2]), x)
 
   expect_is(meme(loc, lab[1], out[1], width = 400, height = 300), x)
   expect_is(meme(loc, lab[1], out[2], width = 400, height = 300), x)
@@ -43,7 +38,18 @@ test_that("meme runs as expected", {
   file.remove(out)
 })
 
+test_that("meme runs as expected; web source", {
+  skip_on_cran()
+  web <- "https://raw.githubusercontent.com/leonawicz/memery/master/data-raw/philosoraptor.png" # a png version
+  expect_is(meme(web, lab[1], out[1]), x)
+  expect_is(meme(web, lab, out[1]), x)
+  expect_is(meme(web, lab[1], out[2]), x)
+  expect_is(meme(web, lab, out[2]), x)
+  file.remove(out)
+})
+
 test_that("meme runs with added font family", {
+  skip_on_cran()
   a <- c("windows", "linux")
   sysname <- tolower(Sys.info()[["sysname"]]) # Skip on Solaris, Mac. Skip on Linux if not TRAVIS.
   skip_if(!sysname %in% a || (sysname == "linux" && !identical(Sys.getenv("TRAVIS"), "true")),
@@ -57,11 +63,12 @@ test_that("meme runs with added font family", {
 })
 
 test_that("meme_gif runs as expected", {
-  pos <- list(w = rep(0.9, 2), h = rep(0.3, 2), x = rep(0.5, 2), y = c(0.9, 0.75))
-  img <- "http://forgifs.com/gallery/d/228621-4/Cat-wiggles.gif"
-
   skip_on_cran()
   skip_on_travis()
+
+  pos <- list(w = rep(0.9, 2), h = rep(0.3, 2), x = rep(0.5, 2), y = c(0.9, 0.75))
+  img <- "https://raw.githubusercontent.com/leonawicz/memery/master/data-raw/cat.gif"
+
   if("magick" %in% installed.packages()){
     s <- c(1.5, 0.75)
     f <- 1:2
